==> raven-2.1.0-0.jar: cljsjs/raven/common/raven.ext.js <==
var Raven = {
  "_hasJSON": {},
  "_hasDocument": {},
  "_lastCapturedException": {},
  "_lastEventId": {},
  "_globalServer": {},
  "_globalKey": {},
  "_globalProject": {},
  "_globalContext": {},
  "_globalOptions": {
    "logger": {},
    "ignoreErrors": {},
    "ignoreUrls": {},
    "whitelistUrls": {},
    "includePaths": {},
    "crossOrigin": {},
    "collectWindowErrors": {},
    "maxMessageLength": {},
    "stackTraceLimit": {}
  },
  "_ignoreOnError": {},
  "_isRavenInstalled": {},
  "_originalErrorStackTraceLimit": {},
  "_originalConsole": {},
  "_originalConsoleMethods": {
    "memory": {},
    "debug": function () {},
    "error": function () {},
    "info": function () {},
    "log": function () {},
    "warn": function () {},
    "dir": function () {},
    "dirxml": function () {},
    "table": function () {},
    "trace": function () {},
    "assert": function () {},
    "count": function () {},
    "markTimeline": function () {},
    "profile": function () {},
    "profileEnd": function () {},
    "time": function () {},
    "timeEnd": function () {},
    "timeStamp": function () {},
    "timeline": function () {},
    "timelineEnd": function () {},
    "group": function () {},
    "groupCollapsed": function () {},
    "groupEnd": function () {},
    "clear": function () {}
  },
  "_plugins": {},
  "_startTime": {},
  "_wrappedBuiltIns": {},
  "noConflict": function () {},
  "VERSION": {},
  "debug": {},
  "TraceKit": {
    "remoteFetching": {},
    "collectWindowErrors": {},
    "linesOfContext": {},
    "debug": {},
    "report": {
      "subscribe": function () {},
      "unsubscribe": function () {},
      "uninstall": function () {}
    },
    "computeStackTrace": {
      "augmentStackTraceWithInitialElement": function () {},
      "computeStackTraceFromStackProp": function () {},
      "guessFunctionName": function () {},
      "gatherContext": function () {}
    }
  },
  "config": function () {},
  "install": function () {},
  "context": function () {},
  "wrap": function () {},
  "uninstall": function () {},
  "captureException": function () {},
  "captureMessage": function () {},
  "addPlugin": function () {},
  "setUserContext": function () {},
  "setExtraContext": function () {},
  "setTagsContext": function () {},
  "clearContext": function () {},
  "getContext": function () {},
  "setRelease": function () {},
  "setDataCallback": function () {},
  "setShouldSendCallback": function () {},
  "setTransport": function () {},
  "lastException": function () {},
  "lastEventId": function () {},
  "isSetup": function () {},
  "afterLoad": function () {},
  "showReportDialog": function () {},
  "_ignoreNextOnError": function () {},
  "_triggerEvent": function () {},
  "_wrapBuiltIns": function () {},
  "_restoreBuiltIns": function () {},
  "_drainPlugins": function () {},
  "_parseDSN": function () {},
  "_getGlobalServer": function () {},
  "_handleOnErrorStackInfo": function () {},
  "_handleStackInfo": function () {},
  "_normalizeFrame": function () {},
  "_extractContextFromFrame": function () {},
  "_processException": function () {},
  "_trimPacket": function () {},
  "_getHttpData": function () {},
  "_send": function () {},
  "_makeImageRequest": function () {},
  "_makeXhrRequest": function () {},
  "_makeRequest": function () {},
  "_newImage": function () {},
  "_logDebug": function () {},
  "_mergeContext": function () {},
  "setUser": function () {},
  "setReleaseContext": function () {}
};

==> raven-3.5.1-0.jar: cljsjs/raven/common/raven.ext.js <==
var Raven = {
  "_hasJSON": {},
  "_hasDocument": {},
  "_lastCapturedException": {},
  "_lastEventId": {},
  "_globalServer": {},
  "_globalKey": {},
  "_globalProject": {},
  "_globalContext": {},
  "_globalOptions": {
    "logger": {},
    "ignoreErrors": {},
    "ignoreUrls": {},
    "whitelistUrls": {},
    "includePaths": {},
    "crossOrigin": {},
    "collectWindowErrors": {},
    "maxMessageLength": {},
    "stackTraceLimit": {},
    "transport": {},
    "allowSecretKey": {},
    "enviroment": {},
    "release": {}
  },
  "_ignoreOnError": {},
  "_isRavenInstalled": {},
  "_originalErrorStackTraceLimit": {},
  "_originalConsole": {},
  "_originalConsoleMethods": {
    "memory": {},
    "debug": function () {},
    "error": function () {},
    "info": function () {},
    "log": function () {},
    "warn": function () {},
    "dir": function () {},
    "dirxml": function () {},
    "table": function () {},
    "trace": function () {},
    "assert": function () {},
    "count": function () {},
    "markTimeline": function () {},
    "profile": function () {},
    "profileEnd": function () {},
    "time": function () {},
    "timeEnd": function () {},
    "timeStamp": function () {},
    "timeline": function () {},
    "timelineEnd": function () {},
    "group": function () {},
    "groupCollapsed": function () {},
    "groupEnd": function () {},
    "clear": function () {}
  },
  "_plugins": {},
  "_startTime": {},
  "_wrappedBuiltIns": {},
  "noConflict": function () {},
  "VERSION": {},
  "debug": {},
  "TraceKit": {
    "remoteFetching": {},
    "collectWindowErrors": {},
    "linesOfContext": {},
    "debug": {},
    "report": {
      "subscribe": function () {},
      "unsubscribe": function () {},
      "uninstall": function () {}
    },
    "computeStackTrace": {
      "augmentStackTraceWithInitialElement": function () {},
      "computeStackTraceFromStackProp": function () {},
      "guessFunctionName": function () {},
      "gatherContext": function () {}
    }
  },
  "config": function () {},
  "install": function () {},
  "context": function () {},
  "wrap": function () {},
  "uninstall": function () {},
  "captureException": function () {},
  "captureMessage": function () {},
  "addPlugin": function () {},
  "setUserContext": function () {},
  "setExtraContext": function () {},
  "setTagsContext": function () {},
  "clearContext": function () {},
  "getContext": function () {},
  "setEnvironment": function() {},
  "setRelease": function () {},
  "setDataCallback": function () {},
  "setShouldSendCallback": function () {},
  "setTransport": function () {},
  "lastException": function () {},
  "lastEventId": function () {},
  "isSetup": function () {},
  "afterLoad": function () {},
  "showReportDialog": function () {},
  "_ignoreNextOnError": function () {},
  "_triggerEvent": function () {},
  "_wrapBuiltIns": function () {},
  "_restoreBuiltIns": function () {},
  "_drainPlugins": function () {},
  "_parseDSN": function () {},
  "_getGlobalServer": function () {},
  "_handleOnErrorStackInfo": function () {},
  "_handleStackInfo": function () {},
  "_normalizeFrame": function () {},
  "_extractContextFromFrame": function () {},
  "_processException": function () {},
  "_trimPacket": function () {},
  "_getHttpData": function () {},
  "_send": function () {},
  "_makeImageRequest": function () {},
  "_makeXhrRequest": function () {},
  "_makeRequest": function () {},
  "_newImage": function () {},
  "_logDebug": function () {},
  "_mergeContext": function () {},
  "setUser": function () {},
  "setReleaseContext": function () {}
};
